@@ -35,9 +35,9 @@ namespace cpptoml
     // a std::map will ensure that entries a sorted, albeit at a slight
     // performance penalty relative to the (default) unordered_map
     using string_to_base_map = std::map<std::string, std::shared_ptr<base>>;
-#else 
+#else
     // by default an unordered_map is used for best performance as the
-    // toml specification does not require entries to be sorted 
+    // toml specification does not require entries to be sorted
     using string_to_base_map = std::unordered_map<std::string, std::shared_ptr<base>>;
 #endif
 
@@ -275,6 +275,20 @@ inline std::shared_ptr<value<T>> base::as()
     return nullptr;
 }
 
+// special case value<double> to allow getting an integer parameter as a
+// double value
+template <>
+inline std::shared_ptr<value<double>> base::as()
+{
+    if (auto v = std::dynamic_pointer_cast<value<double>>(shared_from_this()))
+        return v;
+
+    if (auto v = std::dynamic_pointer_cast<value<int64_t>>(shared_from_this()))
+        return std::make_shared<value<double>>(v->get());
+
+    return nullptr;
+}
+
 class array : public base
 {
   public:
